@@ -2,15 +2,14 @@ use std::path::Path;
 use std::string::ToString;
 use std::{env::current_dir, path::PathBuf};
 
-use anyhow::{anyhow, Result};
-use clap::{arg, Args};
+use anyhow::{Result, anyhow};
+use clap::{Args, arg};
+use dialoguer::{Confirm, FuzzySelect, Input, theme::ColorfulTheme};
 use dirs::config_dir;
 
 use crate::types::{Arch, Assembler, Config, ConfigOptions, ProjectConfig, RootConfig};
 
-use dialoguer::{theme::ColorfulTheme, Confirm, FuzzySelect, Input};
-
-const ARCH_LIST: [Arch; 10] = [
+const ARCH_LIST: [Arch; 11] = [
     Arch::X86,
     Arch::X86_64,
     Arch::X86_AND_X86_64,
@@ -21,15 +20,18 @@ const ARCH_LIST: [Arch; 10] = [
     Arch::MOS6502,
     Arch::PowerISA,
     Arch::Avr,
+    Arch::Mips,
 ];
 
-const ASSEMBLER_LIST: [Assembler; 6] = [
+const ASSEMBLER_LIST: [Assembler; 8] = [
     Assembler::Gas,
     Assembler::Go,
+    Assembler::Mars,
     Assembler::Masm,
     Assembler::Nasm,
     Assembler::Ca65,
     Assembler::Avr,
+    Assembler::Fasm,
 ];
 
 #[derive(Args, Debug, Clone)]
@@ -230,7 +232,9 @@ fn prompt_project_path(opts: &GenerateOpts) -> PathBuf {
                     .default(false)
                     .interact()
                     .unwrap() {
-                       continue;
+                path_entries.clear();
+                display_entries.clear();
+                continue;
             }
             break;
         }
@@ -297,7 +301,9 @@ fn is_executable(path: &Path) -> bool {
                 };
                 let ext_path = PathBuf::from(format!("{path}.{ext}"));
                 if ext_path.exists() && ext_path.is_file() {
-                    println!("Warning: Extended provided path with \".{ext}\" in order to find valid compiler");
+                    println!(
+                        "Warning: Extended provided path with \".{ext}\" in order to find valid compiler"
+                    );
                     return true;
                 }
             }
@@ -477,7 +483,6 @@ fn prompt_config() -> Config {
         instruction_set,
         assembler,
         opts,
-        client: None,
     }
 }
 
