@@ -1,8 +1,11 @@
-use anyhow::{anyhow, Result};
+use anyhow::{Result, anyhow};
 use compile_commands::{CompilationDatabase, SourceFile};
 use log::{error, info, warn};
 use lsp_server::{Connection, Message, Notification, Request, RequestId, Response};
 use lsp_types::{
+    CompletionParams, Diagnostic, DidChangeTextDocumentParams, DidCloseTextDocumentParams,
+    DidOpenTextDocumentParams, DocumentSymbolParams, DocumentSymbolResponse, GotoDefinitionParams,
+    HoverParams, PublishDiagnosticsParams, ReferenceParams, SignatureHelpParams, Uri,
     notification::{
         DidChangeTextDocument, DidCloseTextDocument, DidOpenTextDocument, DidSaveTextDocument,
         Notification as _, PublishDiagnostics,
@@ -11,18 +14,15 @@ use lsp_types::{
         Completion, DocumentDiagnosticRequest, DocumentSymbolRequest, GotoDefinition, HoverRequest,
         References, Request as RequestMessage, SignatureHelpRequest,
     },
-    CompletionParams, Diagnostic, DidChangeTextDocumentParams, DidCloseTextDocumentParams,
-    DidOpenTextDocumentParams, DocumentSymbolParams, DocumentSymbolResponse, GotoDefinitionParams,
-    HoverParams, PublishDiagnosticsParams, ReferenceParams, SignatureHelpParams, Uri,
 };
 use tree_sitter::Parser;
 
 use crate::{
-    apply_compile_cmd, get_comp_resp, get_compile_cmd_for_req, get_default_compile_cmd,
-    get_document_symbols, get_goto_def_resp, get_hover_resp, get_ref_resp, get_sig_help_resp,
-    get_word_from_pos_params, process_uri, send_empty_resp, text_doc_change_to_ts_edit,
     CompletionItems, Config, ConfigOptions, DocumentStore, NameToInstructionMap, RootConfig,
-    ServerStore, TreeEntry, UriConversion,
+    ServerStore, TreeEntry, UriConversion, apply_compile_cmd, get_comp_resp,
+    get_compile_cmd_for_req, get_default_compile_cmd, get_document_symbols, get_goto_def_resp,
+    get_hover_resp, get_ref_resp, get_sig_help_resp, get_word_from_pos_params, process_uri,
+    send_empty_resp, text_doc_change_to_ts_edit,
 };
 
 /// Handles `Request`s from the lsp client
@@ -81,13 +81,7 @@ pub fn handle_request(
         GotoDefinition::METHOD => {
             let (id, params) =
                 cast_req::<GotoDefinition>(req).expect("Failed to cast completion request");
-            handle_goto_def_request(
-                connection,
-                id,
-                &params,
-                config.get_config(&params.text_document_position_params.text_document.uri),
-                doc_store,
-            )?;
+            handle_goto_def_request(connection, id, &params, doc_store)?;
             info!(
                 "{} request serviced in {}ms",
                 GotoDefinition::METHOD,
@@ -97,13 +91,7 @@ pub fn handle_request(
         DocumentSymbolRequest::METHOD => {
             let (id, params) =
                 cast_req::<DocumentSymbolRequest>(req).expect("Failed to cast completion request");
-            handle_document_symbols_request(
-                connection,
-                id,
-                &params,
-                config.get_config(&params.text_document.uri),
-                doc_store,
-            )?;
+            handle_document_symbols_request(connection, id, &params, doc_store)?;
             info!(
                 "{} request serviced in {}ms",
                 DocumentSymbolRequest::METHOD,
@@ -130,13 +118,7 @@ pub fn handle_request(
         References::METHOD => {
             let (id, params) =
                 cast_req::<References>(req).expect("Failed to cast completion request");
-            handle_references_request(
-                connection,
-                id,
-                &params,
-                config.get_config(&params.text_document_position.text_document.uri),
-                doc_store,
-            )?;
+            handle_references_request(connection, id, &params, doc_store)?;
             info!(
                 "{} request serviced in {}ms",
                 References::METHOD,
@@ -305,7 +287,7 @@ pub fn handle_hover_request(
     {
         get_word_from_pos_params(doc, &params.text_document_position_params)
     } else {
-        return send_empty_resp(connection, id, config);
+        return send_empty_resp(connection, id);
     };
 
     // needed to appease the borrow checker, since `word` is a reference to owned
@@ -322,7 +304,7 @@ pub fn handle_hover_request(
         return Ok(connection.sender.send(Message::Response(result))?);
     }
 
-    send_empty_resp(connection, id, config)
+    send_empty_resp(connection, id)
 }
 
 /// Handles completion requests
@@ -343,27 +325,26 @@ pub fn handle_completion_request(
     completion_items: &CompletionItems,
 ) -> Result<()> {
     let uri = &params.text_document_position.text_document.uri;
-    if let Some(doc) = doc_store.text_store.get_document(uri) {
-        if let Some(ref mut tree_entry) = doc_store.tree_store.get_mut(uri) {
-            if let Some(comp_resp) = get_comp_resp(
-                doc.get_content(None),
-                tree_entry,
-                params,
-                config,
-                completion_items,
-            ) {
-                let result = serde_json::to_value(comp_resp).unwrap();
-                let result = Response {
-                    id,
-                    result: Some(result),
-                    error: None,
-                };
-                return Ok(connection.sender.send(Message::Response(result))?);
-            }
-        }
+    if let Some(doc) = doc_store.text_store.get_document(uri)
+        && let Some(ref mut tree_entry) = doc_store.tree_store.get_mut(uri)
+        && let Some(comp_resp) = get_comp_resp(
+            doc.get_content(None),
+            tree_entry,
+            params,
+            config,
+            completion_items,
+        )
+    {
+        let result = serde_json::to_value(comp_resp).unwrap();
+        let result = Response {
+            id,
+            result: Some(result),
+            error: None,
+        };
+        return Ok(connection.sender.send(Message::Response(result))?);
     }
 
-    send_empty_resp(connection, id, config)
+    send_empty_resp(connection, id)
 }
 
 /// Handles go to definition requests
@@ -379,26 +360,24 @@ pub fn handle_goto_def_request(
     connection: &Connection,
     id: RequestId,
     params: &GotoDefinitionParams,
-    config: &Config,
     doc_store: &mut DocumentStore,
 ) -> Result<()> {
     let uri = &params.text_document_position_params.text_document.uri;
-    if let Some(doc) = doc_store.text_store.get_document(uri) {
-        if let Some(tree_entry) = doc_store.tree_store.get_mut(uri) {
-            if let Some(def_resp) = get_goto_def_resp(doc, tree_entry, params) {
-                let result = serde_json::to_value(def_resp).unwrap();
-                let result = Response {
-                    id,
-                    result: Some(result),
-                    error: None,
-                };
+    if let Some(doc) = doc_store.text_store.get_document(uri)
+        && let Some(tree_entry) = doc_store.tree_store.get_mut(uri)
+        && let Some(def_resp) = get_goto_def_resp(doc, tree_entry, params)
+    {
+        let result = serde_json::to_value(def_resp).unwrap();
+        let result = Response {
+            id,
+            result: Some(result),
+            error: None,
+        };
 
-                return Ok(connection.sender.send(Message::Response(result))?);
-            }
-        }
+        return Ok(connection.sender.send(Message::Response(result))?);
     }
 
-    send_empty_resp(connection, id, config)
+    send_empty_resp(connection, id)
 }
 
 /// Handles document symbols requests
@@ -414,26 +393,24 @@ pub fn handle_document_symbols_request(
     connection: &Connection,
     id: RequestId,
     params: &DocumentSymbolParams,
-    config: &Config,
     doc_store: &mut DocumentStore,
 ) -> Result<()> {
     let uri = &params.text_document.uri;
-    if let Some(doc) = doc_store.text_store.get_document(uri) {
-        if let Some(tree_entry) = doc_store.tree_store.get_mut(uri) {
-            if let Some(symbols) = get_document_symbols(doc.get_content(None), tree_entry, params) {
-                let resp = DocumentSymbolResponse::Nested(symbols);
-                let result = serde_json::to_value(resp).unwrap();
-                let result = Response {
-                    id,
-                    result: Some(result),
-                    error: None,
-                };
-                return Ok(connection.sender.send(Message::Response(result))?);
-            }
-        }
+    if let Some(doc) = doc_store.text_store.get_document(uri)
+        && let Some(tree_entry) = doc_store.tree_store.get_mut(uri)
+        && let Some(symbols) = get_document_symbols(doc.get_content(None), tree_entry, params)
+    {
+        let resp = DocumentSymbolResponse::Nested(symbols);
+        let result = serde_json::to_value(resp).unwrap();
+        let result = Response {
+            id,
+            result: Some(result),
+            error: None,
+        };
+        return Ok(connection.sender.send(Message::Response(result))?);
     }
 
-    send_empty_resp(connection, id, config)
+    send_empty_resp(connection, id)
 }
 
 /// Handles signature help requests
@@ -454,30 +431,26 @@ pub fn handle_signature_help_request(
     names_to_instructions: &NameToInstructionMap,
 ) -> Result<()> {
     let uri = &params.text_document_position_params.text_document.uri;
-    if let Some(doc) = doc_store.text_store.get_document(uri) {
-        if let Some(tree_entry) = doc_store.tree_store.get_mut(uri) {
-            let sig_resp = get_sig_help_resp(
-                doc.get_content(None),
-                params,
-                config,
-                tree_entry,
-                names_to_instructions,
-            );
-
-            if let Some(sig) = sig_resp {
-                let result = serde_json::to_value(sig).unwrap();
-                let result = Response {
-                    id,
-                    result: Some(result),
-                    error: None,
-                };
-
-                return Ok(connection.sender.send(Message::Response(result))?);
-            }
-        }
+    if let Some(doc) = doc_store.text_store.get_document(uri)
+        && let Some(tree_entry) = doc_store.tree_store.get_mut(uri)
+        && let Some(sig_resp) = get_sig_help_resp(
+            doc.get_content(None),
+            params,
+            config,
+            tree_entry,
+            names_to_instructions,
+        )
+    {
+        let result = serde_json::to_value(sig_resp).unwrap();
+        let result = Response {
+            id,
+            result: Some(result),
+            error: None,
+        };
+        return Ok(connection.sender.send(Message::Response(result))?);
     }
 
-    send_empty_resp(connection, id, config)
+    send_empty_resp(connection, id)
 }
 
 /// Handles reference requests
@@ -493,27 +466,24 @@ pub fn handle_references_request(
     connection: &Connection,
     id: RequestId,
     params: &ReferenceParams,
-    config: &Config,
     doc_store: &mut DocumentStore,
 ) -> Result<()> {
     let uri = &params.text_document_position.text_document.uri;
-    if let Some(doc) = doc_store.text_store.get_document(uri) {
-        if let Some(tree_entry) = doc_store.tree_store.get_mut(uri) {
-            let ref_resp = get_ref_resp(params, doc, tree_entry);
-            if !ref_resp.is_empty() {
-                let result = serde_json::to_value(&ref_resp).unwrap();
+    if let Some(doc) = doc_store.text_store.get_document(uri)
+        && let Some(tree_entry) = doc_store.tree_store.get_mut(uri)
+    {
+        let ref_resp = get_ref_resp(params, doc, tree_entry);
+        let result = serde_json::to_value(&ref_resp).unwrap();
 
-                let result = Response {
-                    id,
-                    result: Some(result),
-                    error: None,
-                };
-                return Ok(connection.sender.send(Message::Response(result))?);
-            }
-        }
+        let result = Response {
+            id,
+            result: Some(result),
+            error: None,
+        };
+        return Ok(connection.sender.send(Message::Response(result))?);
     }
 
-    send_empty_resp(connection, id, config)
+    send_empty_resp(connection, id)
 }
 
 /// Produces diagnostics and sends a `PublishDiagnostics` notification to the client
@@ -663,18 +633,15 @@ pub fn handle_did_change_text_document_notification(
         .listen(DidChangeTextDocument::METHOD, &raw_params);
 
     let uri = &params.text_document.uri;
-    if let Some(ref mut doc) = doc_store.text_store.get_document(uri) {
-        if let Some(tree_entry) = doc_store.tree_store.get_mut(uri) {
-            if let Some(ref mut curr_tree) = tree_entry.tree {
-                for change in &params.content_changes {
-                    match text_doc_change_to_ts_edit(change, doc) {
-                        Ok(edit) => {
-                            curr_tree.edit(&edit);
-                        }
-                        Err(e) => {
-                            return Err(anyhow!("Bad edit info, failed to edit tree - Error: {e}"));
-                        }
-                    }
+    if let Some(ref mut doc) = doc_store.text_store.get_document(uri)
+        && let Some(tree_entry) = doc_store.tree_store.get_mut(uri)
+        && let Some(ref mut curr_tree) = tree_entry.tree
+    {
+        for change in &params.content_changes {
+            match text_doc_change_to_ts_edit(change, doc) {
+                Ok(edit) => curr_tree.edit(&edit),
+                Err(e) => {
+                    return Err(anyhow!("Bad edit info, failed to edit tree - Error: {e}"));
                 }
             }
         }
