@@ -1,25 +1,29 @@
 use std::{
     collections::{BTreeMap, HashMap, HashSet},
-    fmt::Display,
+    fmt::{Display, Write as _},
     path::PathBuf,
     str::FromStr,
 };
 
+use bincode::{BorrowDecode, Encode};
 use compile_commands::{CompilationDatabase, SourceFile};
 use log::{info, warn};
 use lsp_textdocument::TextDocuments;
 use lsp_types::{CompletionItem, Uri};
+use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 use strum_macros::{AsRefStr, Display, EnumString};
 use tree_sitter::{Parser, Tree};
 
 use crate::{
-    populate_name_to_directive_map, populate_name_to_instruction_map,
-    populate_name_to_register_map, process_uri, UriConversion,
+    UriConversion, populate_name_to_directive_map, populate_name_to_instruction_map,
+    populate_name_to_register_map, process_uri,
 };
 
+pub const BINCODE_CFG: bincode::config::Configuration = bincode::config::standard().with_no_limit();
+
 // Instruction
-#[derive(Debug, Clone, Eq, PartialEq, Hash, Serialize, Deserialize)]
+#[derive(Debug, Clone, Eq, PartialEq, Hash, Serialize, Deserialize, Encode, BorrowDecode)]
 pub struct Instruction {
     pub name: String,
     pub summary: String,
@@ -151,7 +155,9 @@ impl<'own> Instruction {
 
 // TODO: Rework this to use a tagged union...
 // InstructionForm
-#[derive(Default, Eq, PartialEq, Hash, Debug, Clone, Serialize, Deserialize)]
+#[derive(
+    Default, Eq, PartialEq, Hash, Debug, Clone, Serialize, Deserialize, Encode, BorrowDecode,
+)]
 pub struct InstructionForm {
     // --- Gas/Go-Specific Information ---
     pub gas_name: Option<String>,
@@ -182,33 +188,33 @@ impl std::fmt::Display for InstructionForm {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         let mut s = String::new();
         if let Some(val) = &self.gas_name {
-            s += &format!("*GAS*: {val} | ");
+            write!(s, "*GAS*: {val} | ")?;
         }
         if let Some(val) = &self.go_name {
-            s += &format!("*GO*: {val} | ");
+            write!(s, "*GO*: {val} | ")?;
         }
         if let Some(val) = &self.z80_form {
-            s += &format!("*Z80*: {val} | ");
+            write!(s, "*Z80*: {val} | ")?;
         }
         if let Some(val) = &self.avr_mneumonic {
             let version_str = self
                 .avr_version
                 .as_ref()
                 .map_or_else(String::new, |version| format!(" ({version})"));
-            s += &format!("*AVR*: {val}{version_str} | ",);
+            write!(s, "*AVR*: {val}{version_str} | ")?;
         }
 
         if let Some(val) = &self.mmx_mode {
-            s += &(format!("*MMX*: {} | ", val.as_ref()));
+            write!(s, "*MMX*: {} | ", val.as_ref())?;
         }
         if let Some(val) = &self.xmm_mode {
-            s += &(format!("*XMM*: {} | ", val.as_ref()));
+            write!(s, "*XMM*: {} | ", val.as_ref())?;
         }
         if let Some(val) = &self.z80_opcode {
             if val.contains(',') {
-                s += &format!("*Opcodes*: {val} | ");
+                write!(s, "*Opcodes*: {val} | ")?;
             } else {
-                s += &format!("*Opcode*: {val} | ");
+                write!(s, "*Opcode*: {val} | ")?;
             }
         }
 
@@ -218,7 +224,7 @@ impl std::fmt::Display for InstructionForm {
 
         // ISA
         if let Some(val) = &self.isa {
-            s += &format!("*ISA*: {} | ", val.as_ref());
+            write!(s, "*ISA*: {} | ", val.as_ref())?;
         }
 
         if !s.is_empty() {
@@ -234,13 +240,13 @@ impl std::fmt::Display for InstructionForm {
                 .map(|op| {
                     let mut s = format!("  + {:<8}", format!("[{}]", op.type_.as_ref()));
                     if let Some(input) = op.input {
-                        s += &format!(" input = {input:<5} ");
+                        write!(s, " input = {input:<5} ").unwrap();
                     }
                     if let Some(output) = op.output {
-                        s += &format!(" output = {output:<5}");
+                        write!(s, " output = {output:<5}").unwrap();
                     }
                     if let Some(extended_size) = op.extended_size {
-                        s += &format!(" extended-size = {extended_size}");
+                        write!(s, " extended-size = {extended_size}").unwrap();
                     }
 
                     s.trim_end().to_owned()
@@ -252,21 +258,21 @@ impl std::fmt::Display for InstructionForm {
         s += &operands_str;
 
         if let Some(ref timing) = self.z80_timing {
-            s += &format!("\n  + {timing}");
+            write!(s, "\n  + {timing}")?;
         }
 
         if let Some(summary) = &self.avr_summary {
-            s += &format!("\n\n{summary}");
+            write!(s, "\n\n{summary}")?;
         }
         if let Some(sreg) = &self.avr_status_register {
-            s += &format!("\n\n{sreg}");
+            write!(s, "\n\n{sreg}")?;
         }
         if let Some(ref timing) = self.avr_timing {
-            s += &format!("\n\n{timing}\n");
+            writeln!(s, "\n\n{timing}")?;
         }
 
         for url in &self.urls {
-            s += &format!("\n  + More info: {url}\n");
+            writeln!(s, "\n  + More info: {url}")?;
         }
 
         write!(f, "{s}")?;
@@ -275,7 +281,9 @@ impl std::fmt::Display for InstructionForm {
 }
 
 // InstructionAlias
-#[derive(Default, Eq, PartialEq, Hash, Debug, Clone, Serialize, Deserialize)]
+#[derive(
+    Default, Eq, PartialEq, Hash, Debug, Clone, Serialize, Deserialize, Encode, BorrowDecode,
+)]
 pub struct InstructionAlias {
     pub title: String,
     pub summary: String,
@@ -287,11 +295,11 @@ impl std::fmt::Display for InstructionAlias {
         let mut s = self.title.clone();
 
         if !self.summary.is_empty() {
-            s += &format!("\n {}", self.summary);
+            write!(s, "\n {}", self.summary)?;
         }
 
         for template in &self.asm_templates {
-            s += &format!("\n + `{template}`");
+            write!(s, "\n + `{template}`")?;
         }
 
         write!(f, "{s}")?;
@@ -299,7 +307,9 @@ impl std::fmt::Display for InstructionAlias {
     }
 }
 
-#[derive(Debug, Default, PartialEq, Eq, Hash, Clone, Copy, Serialize, Deserialize)]
+#[derive(
+    Debug, Default, PartialEq, Eq, Hash, Clone, Copy, Serialize, Deserialize, Encode, BorrowDecode,
+)]
 pub enum Z80TimingValue {
     #[default]
     Unknown,
@@ -335,7 +345,7 @@ impl FromStr for Z80TimingValue {
     }
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, Hash, Copy, Serialize, Deserialize)]
+#[derive(Debug, Clone, PartialEq, Eq, Hash, Copy, Serialize, Deserialize, Encode, BorrowDecode)]
 pub enum Z80TimingInfo {
     OneNum(Z80TimingValue), // better names here?
     TwoNum((Z80TimingValue, Z80TimingValue)),
@@ -393,7 +403,9 @@ impl FromStr for Z80TimingInfo {
     }
 }
 
-#[derive(Default, Debug, PartialEq, Eq, Hash, Clone, Serialize, Deserialize)]
+#[derive(
+    Default, Debug, PartialEq, Eq, Hash, Clone, Serialize, Deserialize, Encode, BorrowDecode,
+)]
 pub struct Z80Timing {
     pub z80: Z80TimingInfo,
     pub z80_plus_m1: Z80TimingInfo,
@@ -412,7 +424,9 @@ impl Display for Z80Timing {
     }
 }
 
-#[derive(Default, Debug, PartialEq, Eq, Hash, Clone, Serialize, Deserialize)]
+#[derive(
+    Default, Debug, PartialEq, Eq, Hash, Clone, Serialize, Deserialize, Encode, BorrowDecode,
+)]
 pub struct AvrTiming {
     pub avre: Option<String>,
     pub avrxm: Option<String>,
@@ -453,7 +467,9 @@ impl Display for AvrTiming {
     }
 }
 
-#[derive(Default, Debug, PartialEq, Eq, Hash, Clone, Serialize, Deserialize)]
+#[derive(
+    Default, Debug, PartialEq, Eq, Hash, Clone, Serialize, Deserialize, Encode, BorrowDecode,
+)]
 pub struct AvrStatusRegister {
     pub i: char,
     pub t: char,
@@ -478,7 +494,7 @@ impl std::fmt::Display for AvrStatusRegister {
 }
 
 // Directive
-#[derive(Debug, Clone, PartialEq, Eq, Hash, Serialize, Deserialize)]
+#[derive(Debug, Clone, PartialEq, Eq, Hash, Serialize, Deserialize, Encode, BorrowDecode)]
 pub struct Directive {
     pub name: String,
     pub signatures: Vec<String>,
@@ -531,7 +547,7 @@ impl std::fmt::Display for Directive {
         // signature(s)
         let mut sigs = String::new();
         for sig in &self.signatures {
-            sigs += &format!("- {sig}\n");
+            writeln!(sigs, "- {sig}")?;
         }
         v.push(&sigs);
 
@@ -596,7 +612,7 @@ impl<'own> Directive {
 }
 
 // Register
-#[derive(Debug, Clone, PartialEq, Eq, Hash, Serialize, Deserialize)]
+#[derive(Debug, Clone, PartialEq, Eq, Hash, Serialize, Deserialize, Encode, BorrowDecode)]
 pub struct Register {
     pub name: String,
     pub description: Option<String>,
@@ -715,20 +731,58 @@ pub trait Hoverable: Display + Clone {}
 pub trait Completable: Display {}
 pub trait ArchOrAssembler: Clone + Copy {}
 
-#[derive(Debug, Clone, PartialEq, Eq, Hash, EnumString, AsRefStr, Serialize, Deserialize)]
+#[derive(
+    Debug,
+    Clone,
+    PartialEq,
+    Eq,
+    Hash,
+    EnumString,
+    AsRefStr,
+    Serialize,
+    Deserialize,
+    Encode,
+    BorrowDecode,
+)]
 pub enum XMMMode {
     SSE,
     AVX,
 }
 
-#[derive(Debug, Clone, Eq, PartialEq, Hash, EnumString, AsRefStr, Serialize, Deserialize)]
+#[derive(
+    Debug,
+    Clone,
+    Eq,
+    PartialEq,
+    Hash,
+    EnumString,
+    AsRefStr,
+    Serialize,
+    Deserialize,
+    Encode,
+    BorrowDecode,
+)]
 pub enum MMXMode {
     FPU,
     MMX,
 }
 
 #[allow(non_camel_case_types)]
-#[derive(Debug, Hash, PartialEq, Eq, Clone, Copy, EnumString, AsRefStr, Serialize, Deserialize)]
+#[derive(
+    Debug,
+    Hash,
+    PartialEq,
+    Eq,
+    Clone,
+    Copy,
+    EnumString,
+    AsRefStr,
+    Serialize,
+    Deserialize,
+    Encode,
+    BorrowDecode,
+    JsonSchema,
+)]
 pub enum Arch {
     #[strum(serialize = "x86")]
     #[serde(rename = "x86")]
@@ -761,6 +815,9 @@ pub enum Arch {
     #[strum(serialize = "AVR")]
     #[serde(rename = "AVR")] // TODO: lower-case this in the generation code
     Avr,
+    #[strum(serialize = "mips")]
+    #[serde(rename = "mips")]
+    Mips,
     /// For testing purposes *only*. This is not a valid config option
     #[serde(skip)]
     None,
@@ -779,8 +836,8 @@ impl Arch {
             ($arch:expr, $path:literal) => {{
                 let start = std::time::Instant::now();
                 let serialized_regs = include_bytes!($path);
-                let registers = bincode::deserialize::<Vec<Register>>(serialized_regs)
-                    .unwrap_or_else(|e| panic!("Error deserializing {} registers -- {}\nRegenerate serialized data with regenerate.sh", $arch, e));
+                let registers = bincode::borrow_decode_from_slice::<Vec<Register>, _>(serialized_regs, BINCODE_CFG)
+                    .unwrap_or_else(|e| panic!("Error deserializing {} registers -- {}\nRegenerate serialized data with regenerate.sh", $arch, e)).0;
 
                 info!(
                     "{} register set loaded in {}ms",
@@ -793,21 +850,22 @@ impl Arch {
         }
 
         match self {
+            Self::ARM => load_registers_with_path!(Self::ARM, "serialized/registers/arm"),
+            Self::ARM64 => load_registers_with_path!(Self::ARM64, "serialized/registers/arm"),
+            Self::Avr => load_registers_with_path!(Self::Avr, "serialized/registers/avr"),
+            Self::Mips => load_registers_with_path!(Self::Mips, "serialized/registers/mips"),
+            Self::MOS6502 => load_registers_with_path!(Self::MOS6502, "serialized/registers/6502"),
+            Self::PowerISA => {
+                load_registers_with_path!(Self::PowerISA, "serialized/registers/power-isa");
+            }
+            Self::RISCV => load_registers_with_path!(Self::RISCV, "serialized/registers/riscv"),
             Self::X86 => load_registers_with_path!(Self::X86, "serialized/registers/x86"),
             Self::X86_64 => load_registers_with_path!(Self::X86_64, "serialized/registers/x86_64"),
             Self::X86_AND_X86_64 => {
                 load_registers_with_path!(Self::X86, "serialized/registers/x86");
                 load_registers_with_path!(Self::X86_64, "serialized/registers/x86_64");
             }
-            Self::ARM => load_registers_with_path!(Self::ARM, "serialized/registers/arm"),
-            Self::ARM64 => load_registers_with_path!(Self::ARM64, "serialized/registers/arm"),
-            Self::RISCV => load_registers_with_path!(Self::RISCV, "serialized/registers/riscv"),
             Self::Z80 => load_registers_with_path!(Self::Z80, "serialized/registers/z80"),
-            Self::MOS6502 => load_registers_with_path!(Self::MOS6502, "serialized/registers/6502"),
-            Self::PowerISA => {
-                load_registers_with_path!(Self::PowerISA, "serialized/registers/power-isa");
-            }
-            Self::Avr => load_registers_with_path!(Self::Avr, "serialized/registers/avr"),
             Self::None => unreachable!(),
         }
     }
@@ -819,14 +877,16 @@ impl Arch {
     /// Panics if unable to deserialize `Instruction`s
     pub fn setup_instructions(
         self,
+        assembler: Option<Assembler>,
         names_to_instructions: &mut HashMap<(Self, String), Instruction>,
     ) {
         macro_rules! load_instructions_with_path {
             ($arch:expr, $path:literal) => {{
                 let start = std::time::Instant::now();
                 let serialized_instrs = include_bytes!($path);
-                let instructions = bincode::deserialize::<Vec<Instruction>>(serialized_instrs)
-                    .unwrap_or_else(|e| panic!("Error deserializing {} instructions -- {}\nRegenerate serialized data with regenerate.sh", $arch, e));
+                let instructions = bincode::borrow_decode_from_slice::<Vec<Instruction>, _>(serialized_instrs, BINCODE_CFG)
+                    .unwrap_or_else(|e| panic!("Error deserializing {} instructions -- {}\nRegenerate serialized data with regenerate.sh", $arch, e))
+                    .0;
 
                 info!(
                     "{} instruction set loaded in {}ms",
@@ -839,23 +899,29 @@ impl Arch {
         }
 
         match self {
+            Self::ARM => load_instructions_with_path!(Self::ARM, "serialized/opcodes/arm"),
+            // NOTE: Actually, the arm file are all arm64 so we needed to get
+            // the arm32 versions then do the below
+            Self::ARM64 => load_instructions_with_path!(Self::ARM64, "serialized/opcodes/arm"),
+            Self::Avr => load_instructions_with_path!(Self::Avr, "serialized/opcodes/avr"),
+            Self::MOS6502 => load_instructions_with_path!(Self::MOS6502, "serialized/opcodes/6502"),
+            Self::Mips => {
+                load_instructions_with_path!(Self::Mips, "serialized/opcodes/mips");
+                if Some(Assembler::Mars) == assembler {
+                    load_instructions_with_path!(Self::Mips, "serialized/opcodes/mars");
+                }
+            }
+            Self::PowerISA => {
+                load_instructions_with_path!(Self::PowerISA, "serialized/opcodes/power-isa");
+            }
+            Self::RISCV => load_instructions_with_path!(Self::RISCV, "serialized/opcodes/riscv"),
             Self::X86 => load_instructions_with_path!(Self::X86, "serialized/opcodes/x86"),
             Self::X86_64 => load_instructions_with_path!(Self::X86_64, "serialized/opcodes/x86_64"),
             Self::X86_AND_X86_64 => {
                 load_instructions_with_path!(Self::X86, "serialized/opcodes/x86");
                 load_instructions_with_path!(Self::X86_64, "serialized/opcodes/x86_64");
             }
-            Self::ARM => load_instructions_with_path!(Self::ARM, "serialized/opcodes/arm"),
-            // NOTE: Actually, the arm file are all arm64 so we needed to get
-            // the arm32 versions then do the below
-            Self::ARM64 => load_instructions_with_path!(Self::ARM64, "serialized/opcodes/arm"),
-            Self::RISCV => load_instructions_with_path!(Self::RISCV, "serialized/opcodes/riscv"),
             Self::Z80 => load_instructions_with_path!(Self::Z80, "serialized/opcodes/z80"),
-            Self::MOS6502 => load_instructions_with_path!(Self::MOS6502, "serialized/opcodes/6502"),
-            Self::PowerISA => {
-                load_instructions_with_path!(Self::PowerISA, "serialized/opcodes/power-isa");
-            }
-            Self::Avr => load_instructions_with_path!(Self::Avr, "serialized/opcodes/avr"),
             Self::None => unreachable!(),
         }
     }
@@ -899,16 +965,17 @@ impl Default for Arch {
 impl std::fmt::Display for Arch {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
+            Self::ARM => write!(f, "arm")?,
+            Self::ARM64 => write!(f, "arm64")?,
+            Self::Avr => write!(f, "avr")?,
+            Self::Mips => write!(f, "mips")?,
+            Self::MOS6502 => write!(f, "6502")?,
+            Self::PowerISA => write!(f, "power-isa")?,
+            Self::RISCV => write!(f, "riscv")?,
             Self::X86 => write!(f, "x86")?,
             Self::X86_64 => write!(f, "x86-64")?,
             Self::X86_AND_X86_64 => write!(f, "x86/x86-64")?,
-            Self::ARM => write!(f, "arm")?,
-            Self::ARM64 => write!(f, "arm64")?,
-            Self::RISCV => write!(f, "riscv")?,
             Self::Z80 => write!(f, "z80")?,
-            Self::MOS6502 => write!(f, "6502")?,
-            Self::PowerISA => write!(f, "power-isa")?,
-            Self::Avr => write!(f, "avr")?,
             Self::None => write!(f, "None")?,
         }
         Ok(())
@@ -928,8 +995,20 @@ impl std::fmt::Display for Arch {
     AsRefStr,
     Serialize,
     Deserialize,
+    Encode,
+    BorrowDecode,
+    JsonSchema,
 )]
 pub enum Assembler {
+    #[strum(serialize = "avr")]
+    #[serde(rename = "avr")]
+    Avr,
+    #[strum(serialize = "ca65")]
+    #[serde(rename = "ca65")]
+    Ca65,
+    #[strum(serialize = "fasm")]
+    #[serde(rename = "fasm")]
+    Fasm,
     #[default]
     #[strum(serialize = "gas")]
     #[serde(rename = "gas")]
@@ -937,18 +1016,15 @@ pub enum Assembler {
     #[strum(serialize = "go")]
     #[serde(rename = "go")]
     Go,
+    #[strum(serialize = "mars")]
+    #[serde(rename = "mars")]
+    Mars,
     #[strum(serialize = "masm")]
     #[serde(rename = "masm")]
     Masm,
     #[strum(serialize = "nasm")]
     #[serde(rename = "nasm")]
     Nasm,
-    #[strum(serialize = "ca65")]
-    #[serde(rename = "ca65")]
-    Ca65,
-    #[strum(serialize = "avr")]
-    #[serde(rename = "avr")]
-    Avr,
     #[serde(skip)]
     None,
 }
@@ -966,8 +1042,9 @@ impl Assembler {
             ($assembler:expr, $path:literal) => {{
                 let start = std::time::Instant::now();
                 let serialized_dirs = include_bytes!($path);
-                let directives = bincode::deserialize::<Vec<Directive>>(serialized_dirs)
-                    .unwrap_or_else(|e| panic!("Error deserializing {} directives -- {}\nRegenerate serialized data with regenerate.sh", $assembler, e));
+                let directives = bincode::borrow_decode_from_slice::<Vec<Directive>, _>(serialized_dirs, BINCODE_CFG)
+                    .unwrap_or_else(|e| panic!("Error deserializing {} directives -- {}\nRegenerate serialized data with regenerate.sh", $assembler, e))
+                    .0;
 
                 info!(
                     "{} directive set loaded in {}ms",
@@ -980,19 +1057,33 @@ impl Assembler {
         }
 
         match self {
+            Self::Avr => load_directives_with_path!(Self::Avr, "serialized/directives/avr"),
+            Self::Ca65 => load_directives_with_path!(Self::Ca65, "serialized/directives/ca65"),
+            Self::Fasm => load_directives_with_path!(Self::Fasm, "serialized/directives/fasm"),
             Self::Gas => load_directives_with_path!(Self::Gas, "serialized/directives/gas"),
+            Self::Go => warn!("There is currently no Go-specific assembler documentation"),
+            Self::Mars => load_directives_with_path!(Self::Mars, "serialized/directives/mars"),
             Self::Masm => load_directives_with_path!(Self::Masm, "serialized/directives/masm"),
             Self::Nasm => load_directives_with_path!(Self::Nasm, "serialized/directives/nasm"),
-            Self::Go => warn!("There is currently no Go-specific assembler documentation"),
-            Self::Ca65 => load_directives_with_path!(Self::Ca65, "serialized/directives/ca65"),
-            Self::Avr => load_directives_with_path!(Self::Avr, "serialized/directives/avr"),
             Self::None => unreachable!(),
         }
     }
 }
 
 #[derive(
-    Debug, Hash, PartialEq, Eq, Clone, Copy, EnumString, AsRefStr, Display, Serialize, Deserialize,
+    Debug,
+    Hash,
+    PartialEq,
+    Eq,
+    Clone,
+    Copy,
+    EnumString,
+    AsRefStr,
+    Display,
+    Serialize,
+    Deserialize,
+    Encode,
+    BorrowDecode,
 )]
 pub enum RegisterType {
     #[strum(serialize = "General Purpose Register")]
@@ -1022,7 +1113,19 @@ pub enum RegisterType {
 }
 
 #[derive(
-    Debug, Hash, PartialEq, Eq, Clone, Copy, EnumString, AsRefStr, Display, Serialize, Deserialize,
+    Debug,
+    Hash,
+    PartialEq,
+    Eq,
+    Clone,
+    Copy,
+    EnumString,
+    AsRefStr,
+    Display,
+    Serialize,
+    Deserialize,
+    Encode,
+    BorrowDecode,
 )]
 pub enum RegisterWidth {
     #[strum(serialize = "512 bits")]
@@ -1049,7 +1152,9 @@ pub enum RegisterWidth {
     Lower8Lower16,
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, Hash, Serialize, Default, Deserialize)]
+#[derive(
+    Debug, Clone, PartialEq, Eq, Hash, Serialize, Default, Deserialize, Encode, BorrowDecode,
+)]
 pub struct RegisterBitInfo {
     pub bit: u32,
     pub label: String,
@@ -1066,10 +1171,10 @@ impl std::fmt::Display for RegisterBitInfo {
             format!("{:2}: {} - {}", self.bit, self.label, self.description)
         };
         if !self.pae.is_empty() {
-            s += &format!(", PAE: {}", self.pae);
+            write!(s, ", PAE: {}", self.pae)?;
         }
         if !self.long_mode.is_empty() {
-            s += &format!(", Long Mode: {}", self.long_mode);
+            write!(s, " , Long Mode: {}", self.long_mode)?;
         }
 
         write!(f, "{s}")?;
@@ -1077,7 +1182,7 @@ impl std::fmt::Display for RegisterBitInfo {
     }
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize)]
+#[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize, JsonSchema)]
 pub struct RootConfig {
     pub default_config: Option<Config>,
     #[serde(rename = "project")]
@@ -1191,25 +1296,12 @@ impl RootConfig {
         assembler_set.into_iter().collect()
     }
 
-    /// Sets the `client` field of the default config and all project configs
-    pub fn set_client(&mut self, client: LspClient) {
-        if let Some(ref mut root) = self.default_config {
-            root.client = Some(client);
-        }
-
-        if let Some(ref mut projects) = self.projects {
-            for project in projects {
-                project.config.client = Some(client);
-            }
-        }
-    }
-
     #[must_use]
     pub fn is_isa_enabled(&self, isa: Arch) -> bool {
-        if let Some(ref root) = self.default_config {
-            if root.is_isa_enabled(isa) {
-                return true;
-            }
+        if let Some(ref root) = self.default_config
+            && root.is_isa_enabled(isa)
+        {
+            return true;
         }
 
         if let Some(ref projects) = self.projects {
@@ -1225,10 +1317,10 @@ impl RootConfig {
 
     #[must_use]
     pub fn is_assembler_enabled(&self, assembler: Assembler) -> bool {
-        if let Some(ref root) = self.default_config {
-            if root.is_assembler_enabled(assembler) {
-                return true;
-            }
+        if let Some(ref root) = self.default_config
+            && root.is_assembler_enabled(assembler)
+        {
+            return true;
         }
 
         if let Some(ref projects) = self.projects {
@@ -1243,7 +1335,7 @@ impl RootConfig {
     }
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize)]
+#[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize, JsonSchema)]
 pub struct ProjectConfig {
     // Path to a directory or source file on which this config applies
     // Can be relative to the server's root directory, or absolute
@@ -1254,14 +1346,12 @@ pub struct ProjectConfig {
     pub config: Config,
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize)]
+#[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize, JsonSchema)]
 pub struct Config {
     pub version: Option<String>,
     pub assembler: Assembler,
     pub instruction_set: Arch,
     pub opts: Option<ConfigOptions>,
-    #[serde(skip)]
-    pub client: Option<LspClient>,
 }
 
 impl Default for Config {
@@ -1271,12 +1361,12 @@ impl Default for Config {
             assembler: Assembler::default(),
             instruction_set: Arch::default(),
             opts: Some(ConfigOptions::default()),
-            client: None,
         }
     }
 }
 
 impl Config {
+    #[allow(clippy::missing_const_for_fn)]
     #[must_use]
     pub fn get_compiler(&self) -> Option<&str> {
         match self.opts {
@@ -1316,7 +1406,7 @@ impl Config {
     }
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize)]
+#[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize, JsonSchema)]
 pub struct ConfigOptions {
     // Specify compiler to generate diagnostics via `compile_flags.txt`
     pub compiler: Option<String>,
@@ -1341,13 +1431,21 @@ impl Default for ConfigOptions {
     }
 }
 
-#[derive(Debug, Copy, Clone, PartialEq, Eq, Serialize, Deserialize)]
-pub enum LspClient {
-    Helix,
-}
-
 // Instruction Set Architecture
-#[derive(Debug, Copy, Clone, PartialEq, Eq, Hash, EnumString, AsRefStr, Serialize, Deserialize)]
+#[derive(
+    Debug,
+    Copy,
+    Clone,
+    PartialEq,
+    Eq,
+    Hash,
+    EnumString,
+    AsRefStr,
+    Serialize,
+    Deserialize,
+    Encode,
+    BorrowDecode,
+)]
 pub enum ISA {
     #[strum(serialize = "RAO-INT")]
     RAOINT,
@@ -1472,7 +1570,7 @@ pub enum ISA {
 }
 
 // Operand
-#[derive(Debug, PartialEq, Eq, Hash, Clone, Serialize, Deserialize)]
+#[derive(Debug, PartialEq, Eq, Hash, Clone, Serialize, Deserialize, Encode, BorrowDecode)]
 pub struct Operand {
     pub type_: OperandType,
     pub input: Option<bool>,
@@ -1481,7 +1579,19 @@ pub struct Operand {
 }
 
 #[allow(non_camel_case_types)]
-#[derive(Debug, Clone, PartialEq, Eq, Hash, EnumString, AsRefStr, Serialize, Deserialize)]
+#[derive(
+    Debug,
+    Clone,
+    PartialEq,
+    Eq,
+    Hash,
+    EnumString,
+    AsRefStr,
+    Serialize,
+    Deserialize,
+    Encode,
+    BorrowDecode,
+)]
 pub enum OperandType {
     #[strum(serialize = "1")]
     _1,
@@ -1688,7 +1798,7 @@ impl CompletionItems {
 }
 
 /// Struct to store all documentation the server uses to service user requests
-#[derive(Default)]
+#[derive(Default, Debug)]
 pub struct ServerStore {
     /// Links names of instructions, registers, and directives to their documentation
     pub names_to_info: NameToInfoMaps,
