@@ -1,19 +1,21 @@
 use std::path::PathBuf;
 
-use ::asm_lsp::parser::{
-    populate_6502_instructions, populate_arm_instructions, populate_ca65_directives,
-    populate_gas_directives, populate_instructions, populate_masm_nasm_directives,
-    populate_registers, populate_riscv_instructions, populate_riscv_registers,
-};
-use asm_lsp::{
-    parser::{populate_avr_directives, populate_avr_instructions, populate_power_isa_instructions},
-    Arch, Assembler, Directive, Instruction, Register,
-};
-
-use anyhow::{anyhow, Result};
+use anyhow::{Result, anyhow};
 use clap::{Parser, Subcommand};
 use serde::{Deserialize, Serialize};
 
+use asm_lsp::{
+    Arch, Assembler, BINCODE_CFG, Directive, Instruction, Register,
+    parser::{
+        populate_6502_instructions, populate_arm_instructions, populate_avr_directives,
+        populate_avr_instructions, populate_ca65_directives, populate_gas_directives,
+        populate_instructions, populate_mars_pseudo_instructions,
+        populate_masm_nasm_fasm_mars_directives, populate_mips_instructions,
+        populate_power_isa_instructions, populate_registers, populate_riscv_instructions,
+        populate_riscv_registers,
+    },
+};
+
 #[derive(Debug, Clone, Copy, Serialize, Deserialize, clap::ValueEnum)]
 enum DocType {
     Instruction,
@@ -61,7 +63,7 @@ fn run(opts: &SerializeDocs) -> Result<()> {
             let path = opts.input_path.canonicalize()?;
             let instrs: Vec<Instruction>;
             match (path.is_dir(), opts.arch) {
-                (true, Some(arch)) => match arch {
+                (true, Some(arch_in)) => match arch_in {
                     Arch::ARM => {
                         instrs = populate_arm_instructions(&opts.input_path)?;
                     }
@@ -73,7 +75,7 @@ fn run(opts: &SerializeDocs) -> Result<()> {
                     }
                     _ => {
                         return Err(anyhow!(
-                            "Directory parsing for {arch} instructions is not supported"
+                            "Directory parsing for {arch_in} instructions is not supported"
                         ));
                     }
                 },
@@ -84,18 +86,25 @@ fn run(opts: &SerializeDocs) -> Result<()> {
                 }
                 (false, arch_in) => {
                     let conts = std::fs::read_to_string(&path)?;
-                    match arch_in {
-                        Some(Arch::MOS6502) => {
-                            instrs = populate_6502_instructions(&conts)?;
-                        }
-                        Some(Arch::PowerISA) => {
-                            instrs = populate_power_isa_instructions(&conts)?;
-                        }
-                        Some(Arch::Avr) => {
-                            instrs = populate_avr_instructions(&conts)?;
-                        }
-                        _ => {
-                            instrs = populate_instructions(&conts)?;
+                    if opts.assembler == Some(Assembler::Mars) {
+                        instrs = populate_mars_pseudo_instructions(&conts)?;
+                    } else {
+                        match arch_in {
+                            Some(Arch::Mips) => {
+                                instrs = populate_mips_instructions(&conts)?;
+                            }
+                            Some(Arch::MOS6502) => {
+                                instrs = populate_6502_instructions(&conts)?;
+                            }
+                            Some(Arch::PowerISA) => {
+                                instrs = populate_power_isa_instructions(&conts)?;
+                            }
+                            Some(Arch::Avr) => {
+                                instrs = populate_avr_instructions(&conts)?;
+                            }
+                            _ => {
+                                instrs = populate_instructions(&conts)?;
+                            }
                         }
                     }
                 }
@@ -103,7 +112,7 @@ fn run(opts: &SerializeDocs) -> Result<()> {
             if instrs.is_empty() {
                 return Err(anyhow!("Zero instructions read in"));
             }
-            let serialized = bincode::serialize(&instrs)?;
+            let serialized = bincode::encode_to_vec(&instrs, BINCODE_CFG)?;
             std::fs::write(&opts.output_path, serialized)?;
         }
         DocType::Register => {
@@ -129,7 +138,7 @@ fn run(opts: &SerializeDocs) -> Result<()> {
             if regs.is_empty() {
                 return Err(anyhow!("Zero registers read in"));
             }
-            let serialized = bincode::serialize(&regs)?;
+            let serialized = bincode::encode_to_vec(&regs, BINCODE_CFG)?;
             std::fs::write(&opts.output_path, serialized)?;
         }
         DocType::Directive => {
@@ -146,7 +155,9 @@ fn run(opts: &SerializeDocs) -> Result<()> {
                 }
                 (false, Some(assembler_in)) => match assembler_in {
                     Assembler::Gas | Assembler::Go => populate_gas_directives(&conts)?,
-                    Assembler::Masm | Assembler::Nasm => populate_masm_nasm_directives(&conts)?,
+                    Assembler::Masm | Assembler::Nasm | Assembler::Fasm | Assembler::Mars => {
+                        populate_masm_nasm_fasm_mars_directives(&conts)?
+                    }
                     Assembler::Ca65 => populate_ca65_directives(&conts)?,
                     Assembler::Avr => populate_avr_directives(&conts)?,
                     Assembler::None => unreachable!(),
@@ -155,7 +166,7 @@ fn run(opts: &SerializeDocs) -> Result<()> {
             if directives.is_empty() {
                 return Err(anyhow!("Zero directives read in"));
             }
-            let serialized = bincode::serialize(&directives)?;
+            let serialized = bincode::encode_to_vec(&directives, BINCODE_CFG)?;
             std::fs::write(&opts.output_path, serialized)?;
         }
     }
